### R code from vignette source 'multitable.Rnw'

###################################################
### code chunk number 1: multitable.Rnw:30-31
###################################################
options(width=60)


###################################################
### code chunk number 2: multitable.Rnw:34-35
###################################################
options(continue=" ")


###################################################
### code chunk number 3: multitable.Rnw:39-74
###################################################
print.lm <- function (x, digits = max(3, getOption("digits") - 3), ...) 
{
    cat("\nCall:\n", paste(deparse(x$call,width.cutoff = 40L),
    	sep = "\n", collapse = "\n"), "\n\n", sep = "")
    if (length(coef(x))) {
        cat("Coefficients:\n")
        print.default(format(coef(x), digits = digits), print.gap = 2, 
            quote = FALSE)
    }
    else cat("No coefficients\n")
    cat("\n")
    invisible(x)
}

print.rlm <- function (x, ...) 
{
    if (!is.null(cl <- x$call)) {
        cat("\nCall:\n", paste(deparse(x$call,width.cutoff = 40L), 
        sep = "\n", collapse = "\n"), 
        "\n\n", sep = "")
    }
    if (x$converged) 
        cat("Converged in", length(x$conv), "iterations\n")
    else cat("Ran", length(x$conv), "iterations without convergence\n")
    coef <- x$coefficients
    cat("\nCoefficients:\n")
    print(coef, ...)
    nobs <- length(x$residuals)
    rdf <- nobs - length(coef)
    cat("\nDegrees of freedom:", nobs, "total;", rdf, "residual\n")
    if (nzchar(mess <- naprint(x$na.action))) 
        cat("  (", mess, ")\n", sep = "")
    cat("Scale estimate:", format(signif(x$s, 3)), "\n")
    invisible(x)
}


###################################################
### code chunk number 4: multitable.Rnw:257-260
###################################################
library(multitable)
data(fake.community)
fake.community


###################################################
### code chunk number 5: multitable.Rnw:267-268
###################################################
options(width=50)


###################################################
### code chunk number 6: multitable.Rnw:272-273
###################################################
summary(fake.community)


###################################################
### code chunk number 7: multitable.Rnw:282-283
###################################################
fake.community[,c("2008","2009"),]


###################################################
### code chunk number 8: multitable.Rnw:286-287 (eval = FALSE)
###################################################
## fake.community[1:3,"1537",1]


###################################################
### code chunk number 9: multitable.Rnw:293-294
###################################################
options(width=50)


###################################################
### code chunk number 10: multitable.Rnw:298-301
###################################################
fake.community$abundance <- 
  log1p(fake.community$abundance)
fake.community$abundance


###################################################
### code chunk number 11: multitable.Rnw:304-309
###################################################
fake.community$temperature[,"1537"] <- 
  c(5,10,30,20,-80,-10)	
fake.community$precipitation[,"1537"] <- 
  c(5,50,75,50,2,7)
fake.community$body.size["moss"] <- 1


###################################################
### code chunk number 12: multitable.Rnw:312-313
###################################################
options(width=60)


###################################################
### code chunk number 13: multitable.Rnw:319-321
###################################################
lm(abundance ~ body.size*temperature,
data=fake.community)


###################################################
### code chunk number 14: multitable.Rnw:324-326
###################################################
lm(abundance ~ homeotherm*temperature,
data=fake.community)


###################################################
### code chunk number 15: multitable.Rnw:329-332
###################################################
library(MASS)
rlm(abundance ~ body.size*temperature,
data=fake.community)


###################################################
### code chunk number 16: multitable.Rnw:338-339
###################################################
options(width=100)


###################################################
### code chunk number 17: multitable.Rnw:343-344
###################################################
fake.community.df <- as.data.frame(fake.community)


###################################################
### code chunk number 18: multitable.Rnw:349-350
###################################################
fake.community.df


###################################################
### code chunk number 19: multitable.Rnw:355-356
###################################################
options(width=40)


###################################################
### code chunk number 20: multitable.Rnw:362-365
###################################################
library(lattice)
xyplot(abundance ~ temperature | body.size,
  data=fake.community.df)


###################################################
### code chunk number 21: multitable.Rnw:369-370
###################################################
print(xyplot(abundance ~ temperature | body.size,data=fake.community.df))


###################################################
### code chunk number 22: multitable.Rnw:383-392
###################################################
abundance <- data.frame(
	sites=c(
		"midlatitude","subtropical","tropical","equatorial",
		"arctic","midlatitude","tropical","equatorial",
		"subtropical"
	),
	species=c(rep("capybara",4),rep("moss",4),"vampire"),
	abundance=c(4,10,8,7,5,6,9,3,1)
)


###################################################
### code chunk number 23: multitable.Rnw:394-395
###################################################
abundance


###################################################
### code chunk number 24: multitable.Rnw:398-411
###################################################
environment <- data.frame(
	sites=c(
		"subarctic","midlatitude","subtropical",
		"tropical","equatorial"
	),
	temperature=c(0,10,20,50,30),
	precipitation=c(40,20,100,150,200)
)
trait <- data.frame(
	species=c("capybara","moss","vampire"),
	body.size=c(140,5,190),
	metabolic.rate=c(20,5,0)
)


###################################################
### code chunk number 25: multitable.Rnw:413-415
###################################################
environment
trait


###################################################
### code chunk number 26: multitable.Rnw:456-461
###################################################
dl <- dlcast(list(abundance,environment,trait),
	dimids=c("sites","species"),
	fill=c(0,NA,NA)
)
dl


